Deploy to selected resource

A Free Github API Key allows you to use OpenAI models, like gpt-4o

![azureinfo](https://github.com/user-attachments/assets/d27c8baa-a609-4cc0-ad08-484300b3d2fa)

1. Go to https://github.com/ > Signup
2. Go to https://github.com/marketplace/models/azure-openai/gpt-4o or https://github.com/marketplace/models/catalog and select gpt-4o
3. Get API Key > Get production key
4. Sign up and sign in Azure account
6. Select `Deploy to selected resource`
7. Locate the newly created resource under `All resources`
8. Select Azure Open AI
9. Copy one of the `API keys` and `inference endpoint` store it in a secure place

# Setup in ToolMate AI

Setup AI backend either in interactive mode:

> toolmate

or via CLI option:

> tmsetup -m

> Select "Azure" as the backend

> Enter your Azure API key

> Enter your Azure inference endpoint

> select an OpenAI model

![azure1](https://github.com/user-attachments/assets/da0604bc-c876-47ac-bfc0-4a2ff0c4889f)

![azure2](https://github.com/user-attachments/assets/032dd16d-2492-429c-96f4-6850b1b7eeb8)

![azure3](https://github.com/user-attachments/assets/c202d160-396f-44c5-beea-7570ae960560)

